Documentation
¶
Index ¶
- func New() *logger
- type Field
- func Any(key string, val interface{}) Field
- func Duration(key string, val time.Duration) Field
- func Error(key string, val error) Field
- func Int(key string, val int) Field
- func Int16(key string, val int16) Field
- func Int32(key string, val int32) Field
- func Int64(key string, val int64) Field
- func String(key string, val string) Field
- func Uint32(key string, val uint32) Field
- type Logger
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Logger ¶
type Logger interface {
// Use Debug if you want your logs running in development, testing,
// production.
Debug(msg string, fields ...Field)
// Use Info if you want your logs running in production.
Info(msg string, fields ...Field)
// Use Error if you want your logs running in production and you have an error.
Error(msg string, fields ...Field)
With(...Field) *logger
}
Click to show internal directories.
Click to hide internal directories.